History
-------

0.2.3 (2018-10-20)
=======================
* Fix issue with decoding breaking with app codes
* Fix issue with invalid varint decoding

0.1.0 (2018-10-19)
=======================

* First release on PyPI.
